@@ -42,10 +42,10 @@ class Factory(object):
     """
     __metaclass__ = FactoryMetaclass
 
-    def attributes(self, schema, _pyfactory_scope="attributes", **kwargs):
+    def schema(self, schema, **kwargs):
         """
-        This returns the attributes for a particular schema. The attributes
-        are returned as a dict instead of a model instance.
+        This returns the raw schema result for the given name. This will
+        not resolve any special fields.
 
         :Parameters:
           - `schema`: The name of the schema to retrieve.
@@ -59,6 +59,20 @@ class Factory(object):
         # Get the raw result and update it with any overrides from kwargs
         result = self._pyfactory_schemas[schema](self)
         result.update(kwargs)
+        return result
+
+    def attributes(self, schema, _pyfactory_scope="attributes", **kwargs):
+        """
+        This returns the attributes for a particular schema. The attributes
+        are returned as a dict instead of a model instance.
+
+        :Parameters:
+          - `schema`: The name of the schema to retrieve.
+          - `**kwargs` (optional): Any additional keyword arguments given
+            override the attributes returned. This allows for customization
+            of the factory defaults.
+        """
+        result = self.schema(schema, **kwargs)
 
         # Iterate through the result, replacing any special fields as
         # needed...
